API docs for “spamfighter.core.commands.errors.CommandParamsMissingException”

# Class s.c.c.e.CommandParamsMissingException(BaseCommandException):

Part of spamfighter.core.commands.errors View Source View In Hierarchy

Исключение об отсутствии параметров команды

Method | __init__ | Undocumented

Inherited from BaseCommandException:

Method | getCode | Undocumented
Method | getMessage | Undocumented
Method | __str__ | Undocumented

def __init__(self, param): (source)
overrides spamfighter.core.commands.errors.BaseCommandException.__init__
Undocumented